using System;
using System.Linq;
using System.ComponentModel;
using System.Collections.Generic;
using System.IO;
using System.Windows.Forms;

using SwissAcademic.Citavi;
using SwissAcademic.Citavi.Metadata;
using SwissAcademic.Citavi.Shell;
using SwissAcademic.Collections;

// Implementation of macro editor is preliminary and experimental.
// The Citavi object model is subject to change in future version.

public static class CitaviMacro
{
	public static void Main()
	{
		if (Program.ActiveProjectShell == null) return;
		
		Project activeProject = Program.ActiveProjectShell.Project;
		if (activeProject == null) return;
		
		var locations = (from reference in activeProject.References
						from location in reference.Locations
						select location).ToList();
		
		int countInvalidReferenceLocations = 0;
		

		foreach (Location location in locations)
		{
			if (location.LocationType != LocationType.ElectronicAddress) continue;
			
			if (location.AddressUri.AddressInfo == ElectronicAddressInfo.Attachment)
			{
				string fileName = Path.GetFileNameWithoutExtension(location.Address);
				if (location.Address == ".pdf") MessageBox.Show(fileName);
				if (string.IsNullOrEmpty(fileName) || fileName.Length  == 1)
				{
					countInvalidReferenceLocations++;
					location.Address = "#INVALID#" + location.Address;
				}
			}
			else if (location.AddressUri.AddressInfo == ElectronicAddressInfo.AbsoluteFileUri)
			{
				string filePath = Path.GetDirectoryName(location.Address);
				string fileName = Path.GetFileNameWithoutExtension(location.Address);
				string extension = Path.GetExtension(location.Address);
				
				if (string.IsNullOrEmpty(fileName) || fileName.Length  == 1)
				{
					countInvalidReferenceLocations++;
					if (string.IsNullOrEmpty(extension))
					{
						location.Address = filePath + "\\" + "#INVALID#" + fileName;
					}
					else
					{
						location.Address = filePath + "\\" + "#INVALID#" + fileName + extension;
					}
				}
			}
		}

		
		
		if (countInvalidReferenceLocations > 0)
		{
			MessageBox.Show(countInvalidReferenceLocations.ToString() + " locations have been marked as '#INVALID#'.\r\nPlease use the Citavi search (CTRL+F) and search for the term '#INVALID#' to see which locations were affected.", "Citavi");
		}
		else
		{
			MessageBox.Show("No invalid locations found.");
		}
	}
}